@@ -4,7 +4,6 @@ import requests
 
 
 class ServerChecker:
-
     def __init__(self, ip: str, port: str) -> None:
         self.ip = ip
         self.port = port
@@ -15,9 +14,11 @@ class ServerChecker:
 
     def _check_server(self) -> None:
         try:
-            req = requests.post(f"https://companion-rust.facepunch.com/api/server/test_connection?address={self.ip}&port={self.port}")
+            req = requests.post(
+                f"https://companion-rust.facepunch.com/api/server/test_connection?address={self.ip}&port={self.port}"
+            )
             for msg in req.json()["messages"]:
                 if "does not match your outgoing IP address" not in msg:
-                    self.logger.warning(f"Error from server Checker:{msg}")
+                    self.logger.warning(f"Error from server Checker: {msg}")
         except Exception:
             pass
